pub type StudyFabric = Arc<dyn EvalFabric>;Expand description
Shared fabric handle accepted by host adapters without exposing transport.
Aliased Type
pub struct StudyFabric { /* private fields */ }pub type StudyFabric = Arc<dyn EvalFabric>;Shared fabric handle accepted by host adapters without exposing transport.
pub struct StudyFabric { /* private fields */ }